@@ -2,7 +2,7 @@ package Class::DBI::GraphEasy;
 
 use vars qw($VERSION @EXPORT);
 use Exporter;
-use vars qw(@ISA @EXPORT $VERSION);
+use vars qw(@ISA @EXPORT $VERSION $GRAPH_FILL $NODE_FONT $NODE_COLOR $NODE_FILL $NODE_BORDERCOLOR $EDGE_COLOR $COLUMN_NODE_FILL $COLUMN_NODE_FONTSIZE $COLUMN_BORDERCOLOR);
 @ISA = qw(Exporter); 
 @EXPORT = qw(new);
 
@@ -10,7 +10,18 @@ use strict;
 use warnings;
 use Graph::Easy;
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
+
+$GRAPH_FILL = 'white';
+$NODE_FONT = 'Arial';
+$NODE_COLOR = '#666666';
+$NODE_FILL = '#dfefff';
+$NODE_BORDERCOLOR = '#dddddd';
+$EDGE_COLOR = 'grey';
+
+$COLUMN_NODE_FILL = 'white';
+$COLUMN_NODE_FONTSIZE = '0.9em';
+$COLUMN_BORDERCOLOR = '#ff6600';
 
 sub new
 {
@@ -18,19 +29,19 @@ sub new
 	my %args = (@_);
     return unless ref $args{classes} eq 'ARRAY';	
 	my $graph = Graph::Easy->new();
-	$graph->set_attribute('fill','white'); # otherwise firefox 2 will have a black background when rendered as svg
+	$graph->set_attribute('fill', $GRAPH_FILL); # otherwise firefox 2 will have a black background when rendered as svg
 	$graph->set_attribute('flow', $args{flow}) if $args{flow};
 	
-	$graph->set_attribute('node', 'font','Arial');
+	$graph->set_attribute('node', 'font', $NODE_FONT);
 	$graph->set_attribute('node', 'shape', $args{class_shape}) if $args{class_shape};
 	$graph->set_attribute('edge', 'arrowstyle', $args{arrow_style}) if $args{arrow_style};
 	
 	if ($args{colorize})
 	{
-		$graph->set_attribute('node', 'color','#666666');
-		$graph->set_attribute('node', 'fill','#dfefff');
-		$graph->set_attribute('node', 'bordercolor','#dddddd');
-		$graph->set_attribute('edge', 'color','grey')
+		$graph->set_attribute('node', 'color', $NODE_COLOR);
+		$graph->set_attribute('node', 'fill', $NODE_FILL);
+		$graph->set_attribute('node', 'bordercolor', $NODE_BORDERCOLOR);
+		$graph->set_attribute('edge', 'color', $EDGE_COLOR)
 	}
 	
 	return _graph_it(graph => $graph, @_);
@@ -136,15 +147,13 @@ sub _show_columns
 			my $column_name = _prettify(name => $column, prettify => $args{prettify});
 			my ($class_node, $column_node, $edge) = $graph->add_edge($args{class}, $args{class}.'-'.$column);
 			$column_node->set_attribute('label', "$column_name");
-			$column_node->set_attribute('fontsize','0.9em');
+			$column_node->set_attribute('fontsize', $COLUMN_NODE_FONTSIZE);
 			$edge->undirected(1);
 			
 			if ($args{colorize})
 			{
-				$column_node->set_attribute('fill','white');
-				$column_node->set_attribute('color','grey');
-				$column_node->set_attribute('bordercolor','#ff6600');
-				$edge->set_attribute('color','grey');
+				$column_node->set_attribute('fill', $COLUMN_NODE_FILL);
+				$column_node->set_attribute('bordercolor', $COLUMN_BORDERCOLOR);
 			}
 			
 			defined $args{column_shape} ? $column_node->set_attribute('shape', $args{column_shape}):$column_node->set_attribute('shape','circle');
@@ -202,7 +211,7 @@ Defaulted to 0. If set to 1, the module will prettify your class and attribute (
 
 =item colorize => 0 | 1
 
-Defaulted to 0. If set to 1, it will use a default color style. 
+Defaulted to 0. If set to 1, it will use a default color schema. The easiest way to change this is by modifying the values of the exported variables (requires 0.05+).
 
 =item show_columns => 0 | 1
 
